@@ -1,5 +1,5 @@
 #!/usr/bin/env python
 
-from .interactions import Interactions
+from .interactions import Interactions, CommandData
 from .context import CommandContext, AfterCommandContext
 from . import utils
